==> tetry-1.0.0-py3-none-any.whl: tetry/bot/commands.py <==
new = {
    'command': 'new'
}

clearChat = {
    'command': 'clearchat'
}


def authorize(msgid: int, token: str, handling: dict, commit: str):
    return {
        'id': msgid,
        'command': 'authorize',
        'data': {
            'token': token,
            'handling': handling,
            'signature': {
                'commit': {
                    'id': commit
                }
            }
        }
    }


die = {
    'command': 'die'
}

ping = b'\x0B'


def presence(id, status: str, detail: str):
    return {
        'command': 'social.presence',
        'id': id,
        'data': {
            'status': status,
            'detail': detail
        }
    }


def joinroom(room: str, id: int):
    return {
        'id': id,
        'command': 'joinroom',
        'data': room
    }


def createroom(public: bool, id: int):
    if public:
        public = 'public'
    else:
        public = 'private'
    return {
        'id': id,
        'command': 'createroom',
        'data': public
    }


def resume(sockId: str, resume: str):
    return {
        'command': 'resume',
        'socketid': sockId,
        'resumetoken': resume
    }


def hello(msgs: list):
    return {
        'command': 'hello',
        'packets': msgs
    }


def chat(msg: str, id: int):
    return {
        'id': id,
        'command': 'chat',
        'data': msg
    }


def switchBracket(id: int, bracket: str):
    return {
        'id': id,
        'command': 'switchbracket',
        'data': bracket
    }


def switchBracketHost(id: int, bracket: str, uid: str):
    return {
        'id': id,
        'command': 'switchbrackethost',
        'data': {
            'uid': uid,
            'bracket': bracket
        }
    }


def leaveRoom(id):
    return {
        'id': id,
        'command': 'leaveroom',
        'data': False
    }


def transferOwnership(id, uid):
    return {
        'id': id,
        'command': 'transferownership',
        'data': uid
    }


def kick(id, uid):
    return {
        'id': id,
        'command': 'kick',
        'data': uid
    }


def startRoom(id):
    return {
        'id': id,
        'command': 'startroom',
        'data': None
    }


def updateConfig(id, data):
    return {
        'id': id,
        'command': 'updateconfig',
        'data': data
    }


def replay(id, frames, listenId, frame):
    return {
        'command': 'replay',
        'data': {'frames': frames,
                 'listenID': listenId,
                 'provisioned': frame},
        'id': id
    }


def invite(id, uid):
    return {
        'id': id,
        'command': 'social.invite',
        'data': uid
    }


def dm(id, uid, msg):
    return {
        'id': id,
        'command': 'social.dm',
        'data': {
            'recipient': uid,
            'msg': msg
        }
    }


def notificationAck(id):
    msg = {'command': 'social.notifications.ack'}
    if id:
        msg['data'] = id
    return msg

==> tetry-1.1.0-py3-none-any.whl: tetry/bot/commands.py <==
new = {
    'command': 'new'
}

clearChat = {
    'command': 'clearchat'
}


def authorize(msgId: int, token: str, handling: dict, commit: str):
    return {
        'id': msgId,
        'command': 'authorize',
        'data': {
            'token': token,
            'handling': handling,
            'signature': {
                'commit': {
                    'id': commit
                }
            }
        }
    }


die = {
    'command': 'die'
}

ping = b'\x0B'


def presence(msgId, status: str, detail: str):
    return {
        'command': 'social.presence',
        'id': msgId,
        'data': {
            'status': status,
            'detail': detail
        }
    }


def joinroom(room: str, roomId: int):
    return {
        'id': roomId,
        'command': 'joinroom',
        'data': room
    }


def createroom(public: bool, msgId: int):
    if public:
        public = 'public'
    else:
        public = 'private'
    return {
        'id': msgId,
        'command': 'createroom',
        'data': public
    }


def resume(sockId: str, resume: str):
    return {
        'command': 'resume',
        'socketid': sockId,
        'resumetoken': resume
    }


def hello(msgs: list):
    return {
        'command': 'hello',
        'packets': msgs
    }


def chat(msg: str, msgId: int):
    return {
        'id': msgId,
        'command': 'chat',
        'data': msg
    }


def switchBracket(msgId: int, bracket: str):
    return {
        'id': msgId,
        'command': 'switchbracket',
        'data': bracket
    }


def switchBracketHost(msgId: int, bracket: str, uid: str):
    return {
        'id': msgId,
        'command': 'switchbrackethost',
        'data': {
            'uid': uid,
            'bracket': bracket
        }
    }


def leaveRoom(msgId):
    return {
        'id': msgId,
        'command': 'leaveroom',
        'data': False
    }


def transferOwnership(msgId, uid):
    return {
        'id': msgId,
        'command': 'transferownership',
        'data': uid
    }


def kick(msgId, uid):
    return {
        'id': msgId,
        'command': 'kick',
        'data': uid
    }


def startRoom(msgId):
    return {
        'id': msgId,
        'command': 'startroom',
        'data': None
    }


def updateConfig(msgId, data):
    return {
        'id': msgId,
        'command': 'updateconfig',
        'data': data
    }


def replay(msgId, frames, listenId, frame):
    return {
        'command': 'replay',
        'data': {'frames': frames,
                 'listenID': listenId,
                 'provisioned': frame},
        'id': msgId
    }


def invite(msgId, uid):
    return {
        'id': msgId,
        'command': 'social.invite',
        'data': uid
    }


def dm(msgId, uid, msg):
    return {
        'id': msgId,
        'command': 'social.dm',
        'data': {
            'recipient': uid,
            'msg': msg
        }
    }


def notificationAck(notif):
    msg = {'command': 'social.notifications.ack'}
    if notif:
        msg['data'] = notif
    return msg
